aboutsummaryrefslogtreecommitdiff
path: root/src/com.example.portfolio2/com/example/portfolio2/Controller.java
diff options
context:
space:
mode:
Diffstat (limited to 'src/com.example.portfolio2/com/example/portfolio2/Controller.java')
-rw-r--r--src/com.example.portfolio2/com/example/portfolio2/Controller.java11
1 files changed, 5 insertions, 6 deletions
diff --git a/src/com.example.portfolio2/com/example/portfolio2/Controller.java b/src/com.example.portfolio2/com/example/portfolio2/Controller.java
index 91236ea..e249863 100644
--- a/src/com.example.portfolio2/com/example/portfolio2/Controller.java
+++ b/src/com.example.portfolio2/com/example/portfolio2/Controller.java
@@ -37,11 +37,11 @@ class Controller {
/// callback when category has been selected
///
/// @param combo involved activity box
/// @param select selected item
/// @param area whole text area
void onCategorySelected(
- final ComboBox<String> combo,
+ final String category,
final ComboBox<String> select,
final TextArea area
) {
@@ -53,8 +53,7 @@ class Controller {
area.clear();
// fill activity box from data in store
- select.getItems().addAll(
- store.selectProgram(combo.getValue()));
+ select.getItems().addAll(store.selectProgram(category));
}
/// callback when activity has been selected
@@ -37,11 +37,11 @@ class Controller {
/// callback when category has been selected
///
- /// @param combo involved activity box
- /// @param select selected item
- /// @param area whole text area
+ /// @param category selected category
+ /// @param select selected item
+ /// @param area whole text area
void onCategorySelected(